@@ -151,7 +151,8 @@
 			 *unbound-variable-hook* *load-hook* *rootlet-redefinition-hook* *missing-close-paren-hook* *read-error-hook*
 			 tree-count ; signature is kinda silly here
 			 c-define-1 apropos map-values trace-in profile-in
-			 define-expansion))
+			 define-expansion
+			 heap-scan heap-analyze heap-holders heap-holder))
   
   (define (test-sym sym)
     (when (and (not (memq sym baddies))
@@ -330,19 +331,20 @@
 		 probes))))))))
   
   (define baddies '(exit emergency-exit abort s7-optimize dynamic-unwind 
-			 delete-file system set-cdr! stacktrace check check-funcs type-ok
-			 cutlet varlet gc cond-expand reader-cond
-			 openlet coverlet eval ;vector list cons values hash-table
-			 symbol-table load throw error
-			 make-rectangular macro macro* bacro bacro*
-			 copy fill! hash-table-set! vector-set! let-set! list-values apply-values immutable!
-			 *unbound-variable-hook* *load-hook* *rootlet-redefinition-hook* *missing-close-paren-hook* *read-error-hook*
-			 tree-count ; signature is kinda silly here
-			 trace-in profile-in apply call-with-exit
-			 define-expansion call-with-current-continuation vector-append append ; append gets uninteresting type conversion complaints
-			 call/cc call-with-output-string open-input-function open-output-function
-			 set-current-input-port set-current-output-port set-current-error-port 
-			 ))
+		    delete-file system set-cdr! stacktrace check check-funcs type-ok
+		    cutlet varlet gc cond-expand reader-cond
+		    openlet coverlet eval ;vector list cons values hash-table
+		    symbol-table load throw error
+		    make-rectangular macro macro* bacro bacro*
+		    copy fill! hash-table-set! vector-set! let-set! list-values apply-values immutable!
+		    *unbound-variable-hook* *load-hook* *rootlet-redefinition-hook* *missing-close-paren-hook* *read-error-hook*
+		    tree-count ; signature is kinda silly here
+		    trace-in profile-in apply call-with-exit
+		    define-expansion call-with-current-continuation vector-append append ; append gets uninteresting type conversion complaints
+		    call/cc call-with-output-string open-input-function open-output-function
+		    set-current-input-port set-current-output-port set-current-error-port
+		    heap-scan heap-analyze heap-holders heap-holder
+		    ))
   
   (define (check-funcs)
     (let ((syms (symbol-table)))
